@@ -1,25 +1,12 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from dataclasses import dataclass
-from enum import Enum
 from typing import List, Optional
 
-from pontos.models import Model
+from pontos.models import Model, StrEnum
 
 __all__ = (
     "App",
@@ -35,7 +22,7 @@ __all__ = (
 )
 
 
-class FileStatus(Enum):
+class FileStatus(StrEnum):
     """
     File status
 
@@ -110,7 +97,7 @@ class User(GitHubModel):
     site_admin: bool
 
 
-class TeamPrivacy(Enum):
+class TeamPrivacy(StrEnum):
     """
     Team privacy
 
@@ -123,7 +110,7 @@ class TeamPrivacy(Enum):
     CLOSED = "closed"
 
 
-class TeamRole(Enum):
+class TeamRole(StrEnum):
     """
     A user's role withing a team
 
@@ -137,7 +124,7 @@ class TeamRole(Enum):
     MAINTAINER = "maintainer"
 
 
-class Permission(Enum):
+class Permission(StrEnum):
     # pylint: disable=line-too-long
     """
     Permissions on a repository/project at GitHub
@@ -225,7 +212,7 @@ class App(GitHubModel):
     events: List[str]
 
 
-class Event(Enum):
+class Event(StrEnum):
     """
     A GitHub event type
 
@@ -309,7 +296,7 @@ class Event(Enum):
     WORKFLOW_RUN = "workflow_run"
 
 
-class SortOrder(Enum):
+class SortOrder(StrEnum):
     """
     Sort order: asc or desc
 
