@@ -33,6 +33,7 @@ from pontos.helper import snake_case
 SLEEP_TIMEOUT = 30.0  # in seconds
 DEFAULT_TIMEOUT = 180.0  # three minutes
 DEFAULT_TIMEOUT_CONFIG = Timeout(DEFAULT_TIMEOUT)  # three minutes
+RETRY_DELAY = 2.0  # in seconds
 
 Headers = Dict[str, str]
 Params = Dict[str, Union[str, int]]
@@ -267,43 +268,48 @@ class NVDResults(Generic[T], AsyncIterable[T], Awaitable["NVDResults"]):
 
     async def _load_next_data(self) -> None:
         if (
-            self._current_request_results is None
-            or self._downloaded_results < self._current_request_results
+            self._current_request_results is not None
+            and self._downloaded_results >= self._current_request_results
         ):
-            params = self._params
-            params["startIndex"] = self._current_index
-
-            if self._current_results_per_page is not None:
-                params["resultsPerPage"] = self._current_results_per_page
-
-            response = await self._api._get(params=params)
-            response.raise_for_status()
-
-            self._url = response.url
-            data: JSON = response.json(object_hook=convert_camel_case)
-
-            self._data = data
-            self._current_results_per_page = int(data["results_per_page"])  # type: ignore
-            self._total_results = int(data["total_results"])  # type: ignore
-            self._current_index += self._current_results_per_page
-            self._downloaded_results += self._current_results_per_page
-
-            if not self._current_request_results:
-                self._current_request_results = self._total_results
-
-            if (
-                self._request_results
-                and self._downloaded_results + self._current_results_per_page
-                > self._request_results
-            ):
-                # avoid downloading more results then requested
-                self._current_results_per_page = (
-                    self._request_results - self._downloaded_results
-                )
-
-        else:
             raise NoMoreResults()
 
+        if (
+            self._total_results is not None
+            and self._current_index >= self._total_results
+        ):
+            raise NoMoreResults()
+
+        params = self._params
+        params["startIndex"] = self._current_index
+
+        if self._current_results_per_page is not None:
+            params["resultsPerPage"] = self._current_results_per_page
+
+        response = await self._api._get(params=params)
+        response.raise_for_status()
+
+        self._url = response.url
+        data: JSON = response.json(object_hook=convert_camel_case)
+
+        self._data = data
+        self._current_results_per_page = int(data["results_per_page"])  # type: ignore
+        self._total_results = int(data["total_results"])  # type: ignore
+        self._current_index += self._current_results_per_page
+        self._downloaded_results += self._current_results_per_page
+
+        if not self._current_request_results:
+            self._current_request_results = self._total_results
+
+        if (
+            self._request_results
+            and self._downloaded_results + self._current_results_per_page
+            > self._request_results
+        ):
+            # avoid downloading more results then requested
+            self._current_results_per_page = (
+                self._request_results - self._downloaded_results
+            )
+
     async def _get_next_iterator(self) -> Iterator[T]:
         await self._load_next_data()
         return self._result_func(self._data)  # type: ignore
@@ -337,6 +343,7 @@ class NVDApi(ABC):
         token: Optional[str] = None,
         timeout: Optional[Timeout] = DEFAULT_TIMEOUT_CONFIG,
         rate_limit: bool = True,
+        request_attempts: int = 1,
     ) -> None:
         """
         Create a new instance of the CVE API.
@@ -352,6 +359,7 @@ class NVDApi(ABC):
                 rolling 30 second window.
                 See https://nvd.nist.gov/developers/start-here#divRateLimits
                 Default: True.
+            request_attempts: The number of attempts per HTTP request. Defaults to 1.
         """
         self._url = url
         self._token = token
@@ -365,6 +373,8 @@ class NVDApi(ABC):
         self._request_count = 0
         self._last_sleep = time.monotonic()
 
+        self._request_attempts = request_attempts
+
     def _request_headers(self) -> Headers:
         """
         Get the default request headers
@@ -404,9 +414,19 @@ class NVDApi(ABC):
         """
         headers = self._request_headers()
 
-        await self._consider_rate_limit()
+        for attempt in range(self._request_attempts):
+            if attempt > 0:
+                delay = RETRY_DELAY**attempt
+                await asyncio.sleep(delay)
 
-        return await self._client.get(self._url, headers=headers, params=params)
+            await self._consider_rate_limit()
+            response = await self._client.get(
+                self._url, headers=headers, params=params
+            )
+            if not response.is_server_error:
+                break
+
+        return response
 
     async def __aenter__(self) -> "NVDApi":
         # reset rate limit counter
