@@ -1,58 +1,45 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from dataclasses import dataclass
-from enum import Enum
 from typing import Optional
 
-from pontos.models import Model
+from pontos.models import Model, StrEnum
 
 
-class Severity(Enum):
+class Severity(StrEnum):
     LOW = "LOW"
     MEDIUM = "MEDIUM"
     HIGH = "HIGH"
 
 
-class AccessVector(Enum):
+class AccessVector(StrEnum):
     NETWORK = "NETWORK"
     ADJACENT_NETWORK = "ADJACENT_NETWORK"
     LOCAL = "LOCAL"
 
 
-class AccessComplexity(Enum):
+class AccessComplexity(StrEnum):
     HIGH = "HIGH"
     MEDIUM = "MEDIUM"
     LOW = "LOW"
 
 
-class Authentication(Enum):
+class Authentication(StrEnum):
     MULTIPLE = "MULTIPLE"
     SINGLE = "SINGLE"
     NONE = "NONE"
 
 
-class Impact(Enum):
+class Impact(StrEnum):
     NONE = "NONE"
     PARTIAL = "PARTIAL"
     COMPLETE = "COMPLETE"
 
 
-class Exploitability(Enum):
+class Exploitability(StrEnum):
     UNPROVEN = "UNPROVEN"
     PROOF_OF_CONCEPT = "PROOF_OF_CONCEPT"
     FUNCTIONAL = "FUNCTIONAL"
@@ -60,7 +47,7 @@ class Exploitability(Enum):
     NOT_DEFINED = "NOT_DEFINED"
 
 
-class RemediationLevel(Enum):
+class RemediationLevel(StrEnum):
     OFFICIAL_FIX = "OFFICIAL_FIX"
     TEMPORARY_FIX = "TEMPORARY_FIX"
     WORKAROUND = "WORKAROUND"
@@ -68,14 +55,14 @@ class RemediationLevel(Enum):
     NOT_DEFINED = "NOT_DEFINED"
 
 
-class ReportConfidence(Enum):
+class ReportConfidence(StrEnum):
     UNCONFIRMED = "UNCONFIRMED"
     UNCORROBORATED = "UNCORROBORATED"
     CONFIRMED = "CONFIRMED"
     NOT_DEFINED = "NOT_DEFINED"
 
 
-class CollateralDamagePotential(Enum):
+class CollateralDamagePotential(StrEnum):
     NONE = "NONE"
     LOW = "LOW"
     LOW_MEDIUM = "LOW_MEDIUM"
@@ -84,7 +71,7 @@ class CollateralDamagePotential(Enum):
     NOT_DEFINED = "NOT_DEFINED"
 
 
-class TargetDistribution(Enum):
+class TargetDistribution(StrEnum):
     NONE = "NONE"
     LOW = "LOW"
     MEDIUM = "MEDIUM"
@@ -92,7 +79,7 @@ class TargetDistribution(Enum):
     NOT_DEFINED = "NOT_DEFINED"
 
 
-class Requirement(Enum):
+class Requirement(StrEnum):
     LOW = "LOW"
     MEDIUM = "MEDIUM"
     HIGH = "HIGH"
