@@ -2,18 +2,6 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import unittest
 from pathlib import Path
 
@@ -26,10 +14,8 @@ class ParseArgsTestCase(unittest.TestCase):
         parsed_args = parse_args(
             [
                 "-q",
-                "--project",
-                "urghs",
-                "--space",
-                "bla",
+                "--repository",
+                "urghs/bla",
                 "--config",
                 "foo.toml",
                 "--current-version",
@@ -44,8 +30,7 @@ class ParseArgsTestCase(unittest.TestCase):
         )
 
         self.assertTrue(parsed_args.quiet)
-        self.assertEqual(parsed_args.project, "urghs")
-        self.assertEqual(parsed_args.space, "bla")
+        self.assertEqual(parsed_args.repository, "urghs/bla")
         self.assertEqual(parsed_args.config, Path("foo.toml"))
         self.assertEqual(parsed_args.current_version, PEP440Version("1.2.3"))
         self.assertEqual(parsed_args.next_version, PEP440Version("2.3.4"))
