@@ -1,23 +1,13 @@
+# SPDX-FileCopyrightText: 2023 Greenbone AG
+#
 # SPDX-License-Identifier: GPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=line-too-long
 # ruff: noqa: E501
 
 import unittest
-from datetime import datetime
+from datetime import datetime, timezone
+from uuid import UUID
 
 from pontos.nvd.models.cpe import CPE, ReferenceType
 from tests.nvd import get_cpe_data
@@ -32,13 +22,17 @@ class CPETestCase(unittest.TestCase):
             "cpe:2.3:o:microsoft:windows_10_22h2:-:*:*:*:*:*:arm64:*",
         )
         self.assertEqual(
-            cpe.cpe_name_id, "9BAECDB2-614D-4E9C-9936-190C30246F03"
+            cpe.cpe_name_id, UUID("9BAECDB2-614D-4E9C-9936-190C30246F03")
         )
         self.assertFalse(cpe.deprecated)
         self.assertEqual(
-            cpe.last_modified, datetime(2022, 12, 9, 18, 15, 16, 973000)
+            cpe.last_modified,
+            datetime(2022, 12, 9, 18, 15, 16, 973000, tzinfo=timezone.utc),
+        )
+        self.assertEqual(
+            cpe.created,
+            datetime(2022, 12, 9, 16, 20, 6, 943000, tzinfo=timezone.utc),
         )
-        self.assertEqual(cpe.created, datetime(2022, 12, 9, 16, 20, 6, 943000))
 
         self.assertEqual(cpe.titles, [])
         self.assertEqual(cpe.refs, [])
@@ -111,5 +105,6 @@ class CPETestCase(unittest.TestCase):
             "cpe:2.3:o:microsoft:windows_10_22h2:-:*:*:*:*:*:x64:*",
         )
         self.assertEqual(
-            deprecated_by.cpe_name_id, "A09335E2-B42F-4820-B487-57A4BF0CEE98"
+            deprecated_by.cpe_name_id,
+            UUID("A09335E2-B42F-4820-B487-57A4BF0CEE98"),
         )
